"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DT:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DTEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DT.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Unknown: _DT.ValueType  # 0
    """未知"""
    Phone: _DT.ValueType  # 1
    """手机端"""
    Pad: _DT.ValueType  # 2
    """ipad端"""
    PC: _DT.ValueType  # 3
    """web端"""
    TV: _DT.ValueType  # 4
    """TV端"""
    Car: _DT.ValueType  # 5
    """车机端"""
    Iot: _DT.ValueType  # 6
    """物联设备"""
    AndPad: _DT.ValueType  # 7
    """apad端"""

class DT(_DT, metaclass=_DTEnumTypeWrapper):
    """设备标识代码"""

Unknown: DT.ValueType  # 0
"""未知"""
Phone: DT.ValueType  # 1
"""手机端"""
Pad: DT.ValueType  # 2
"""ipad端"""
PC: DT.ValueType  # 3
"""web端"""
TV: DT.ValueType  # 4
"""TV端"""
Car: DT.ValueType  # 5
"""车机端"""
Iot: DT.ValueType  # 6
"""物联设备"""
AndPad: DT.ValueType  # 7
"""apad端"""
global___DT = DT

class _HistorySource:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HistorySourceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HistorySource.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    history_VALUE: _HistorySource.ValueType  # 0
    """主站历史记录页"""
    shopping_VALUE: _HistorySource.ValueType  # 1
    """会员购浏览记录"""

class HistorySource(_HistorySource, metaclass=_HistorySourceEnumTypeWrapper):
    """搜索历史记录来源"""

history_VALUE: HistorySource.ValueType  # 0
"""主站历史记录页"""
shopping_VALUE: HistorySource.ValueType  # 1
"""会员购浏览记录"""
global___HistorySource = HistorySource

@typing_extensions.final
class CardArticle(google.protobuf.message.Message):
    """专栏卡片"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVERS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    DISPLAYATTENTION_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    @property
    def covers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """封面url"""
    name: builtins.str
    """UP主昵称"""
    mid: builtins.int
    """UP主mid"""
    displayAttention: builtins.bool
    """是否展示关注按钮"""
    badge: builtins.str
    """角标"""
    @property
    def relation(self) -> global___Relation:
        """关系信息"""
    def __init__(
        self,
        *,
        covers: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        mid: builtins.int = ...,
        displayAttention: builtins.bool = ...,
        badge: builtins.str = ...,
        relation: global___Relation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "covers", b"covers", "displayAttention", b"displayAttention", "mid", b"mid", "name", b"name", "relation", b"relation"]) -> None: ...

global___CardArticle = CardArticle

@typing_extensions.final
class CardCheese(google.protobuf.message.Message):
    """课程卡片"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """封面url"""
    progress: builtins.int
    """观看进度"""
    duration: builtins.int
    """总计时长"""
    subtitle: builtins.str
    """单集标题"""
    state: builtins.int
    """"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        progress: builtins.int = ...,
        duration: builtins.int = ...,
        subtitle: builtins.str = ...,
        state: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "duration", b"duration", "progress", b"progress", "state", b"state", "subtitle", b"subtitle"]) -> None: ...

global___CardCheese = CardCheese

@typing_extensions.final
class CardLive(google.protobuf.message.Message):
    """直播卡片"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    STSTUS_FIELD_NUMBER: builtins.int
    DISPLAY_ATTENTION_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """封面url"""
    name: builtins.str
    """主播昵称"""
    mid: builtins.int
    """主播mid"""
    tag: builtins.str
    """直播分区名"""
    ststus: builtins.int
    """直播状态"""
    display_attention: builtins.bool
    """是否展示关注按钮"""
    @property
    def relation(self) -> global___Relation:
        """关系信息"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        name: builtins.str = ...,
        mid: builtins.int = ...,
        tag: builtins.str = ...,
        ststus: builtins.int = ...,
        display_attention: builtins.bool = ...,
        relation: global___Relation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "display_attention", b"display_attention", "mid", b"mid", "name", b"name", "relation", b"relation", "ststus", b"ststus", "tag", b"tag"]) -> None: ...

global___CardLive = CardLive

@typing_extensions.final
class CardOGV(google.protobuf.message.Message):
    """pgc稿件卡片"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    BADGE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """封面url"""
    progress: builtins.int
    """观看进度"""
    duration: builtins.int
    """总计时长"""
    subtitle: builtins.str
    """单集标题"""
    badge: builtins.str
    """"""
    state: builtins.int
    """"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        progress: builtins.int = ...,
        duration: builtins.int = ...,
        subtitle: builtins.str = ...,
        badge: builtins.str = ...,
        state: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge", b"badge", "cover", b"cover", "duration", b"duration", "progress", b"progress", "state", b"state", "subtitle", b"subtitle"]) -> None: ...

global___CardOGV = CardOGV

@typing_extensions.final
class CardUGC(google.protobuf.message.Message):
    """ugc稿件卡片"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COVER_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    DISPLAY_ATTENTION_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    RELATION_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    SHORT_LINK_FIELD_NUMBER: builtins.int
    SHARE_SUBTITLE_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    cover: builtins.str
    """封面url"""
    progress: builtins.int
    """观看进度"""
    duration: builtins.int
    """视频长度"""
    name: builtins.str
    """UP主昵称"""
    mid: builtins.int
    """UP主mid"""
    display_attention: builtins.bool
    """是否展示关注按钮"""
    cid: builtins.int
    """历史观看视频cid"""
    page: builtins.int
    """历史观看视频分P"""
    subtitle: builtins.str
    """历史观看视频分P的标题"""
    @property
    def relation(self) -> global___Relation:
        """关系信息"""
    bvid: builtins.str
    """稿件bvid"""
    videos: builtins.int
    """总分P数"""
    short_link: builtins.str
    """短链接"""
    share_subtitle: builtins.str
    """分享副标题"""
    view: builtins.int
    """播放数"""
    state: builtins.int
    """"""
    def __init__(
        self,
        *,
        cover: builtins.str = ...,
        progress: builtins.int = ...,
        duration: builtins.int = ...,
        name: builtins.str = ...,
        mid: builtins.int = ...,
        display_attention: builtins.bool = ...,
        cid: builtins.int = ...,
        page: builtins.int = ...,
        subtitle: builtins.str = ...,
        relation: global___Relation | None = ...,
        bvid: builtins.str = ...,
        videos: builtins.int = ...,
        short_link: builtins.str = ...,
        share_subtitle: builtins.str = ...,
        view: builtins.int = ...,
        state: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["relation", b"relation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bvid", b"bvid", "cid", b"cid", "cover", b"cover", "display_attention", b"display_attention", "duration", b"duration", "mid", b"mid", "name", b"name", "page", b"page", "progress", b"progress", "relation", b"relation", "share_subtitle", b"share_subtitle", "short_link", b"short_link", "state", b"state", "subtitle", b"subtitle", "videos", b"videos", "view", b"view"]) -> None: ...

global___CardUGC = CardUGC

@typing_extensions.final
class ClearReq(google.protobuf.message.Message):
    """清空历史记录-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUSINESS_FIELD_NUMBER: builtins.int
    business: builtins.str
    """业务类型
    archive:视频 live:直播 article:专栏 goods:商品 show:展演
    """
    def __init__(
        self,
        *,
        business: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["business", b"business"]) -> None: ...

global___ClearReq = ClearReq

@typing_extensions.final
class Cursor(google.protobuf.message.Message):
    """游标信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_FIELD_NUMBER: builtins.int
    MAXTP_FIELD_NUMBER: builtins.int
    max: builtins.int
    """本页最大值游标值"""
    maxTp: builtins.int
    """本页最大值游标类型"""
    def __init__(
        self,
        *,
        max: builtins.int = ...,
        maxTp: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max", b"max", "maxTp", b"maxTp"]) -> None: ...

global___Cursor = Cursor

@typing_extensions.final
class CursorItem(google.protobuf.message.Message):
    """历史记录卡片信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CARD_UGC_FIELD_NUMBER: builtins.int
    CARD_OGV_FIELD_NUMBER: builtins.int
    CARD_ARTICLE_FIELD_NUMBER: builtins.int
    CARD_LIVE_FIELD_NUMBER: builtins.int
    CARD_CHEESE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    VIEWAT_FIELD_NUMBER: builtins.int
    KID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    BUSINESS_FIELD_NUMBER: builtins.int
    TP_FIELD_NUMBER: builtins.int
    DT_FIELD_NUMBER: builtins.int
    HAS_SHARE_FIELD_NUMBER: builtins.int
    @property
    def card_ugc(self) -> global___CardUGC:
        """ugc稿件"""
    @property
    def card_ogv(self) -> global___CardOGV:
        """pgc稿件"""
    @property
    def card_article(self) -> global___CardArticle:
        """专栏"""
    @property
    def card_live(self) -> global___CardLive:
        """直播"""
    @property
    def card_cheese(self) -> global___CardCheese:
        """课程"""
    title: builtins.str
    """标题"""
    uri: builtins.str
    """目标uri/url"""
    viewAt: builtins.int
    """观看时间"""
    kid: builtins.int
    """历史记录id"""
    oid: builtins.int
    """业务id"""
    business: builtins.str
    """业务类型
    archive:视频 live:直播 article:专栏 goods:商品 show:展演
    """
    tp: builtins.int
    """业务类型代码"""
    @property
    def dt(self) -> global___DeviceType:
        """设备标识"""
    has_share: builtins.bool
    """是否有分享按钮"""
    def __init__(
        self,
        *,
        card_ugc: global___CardUGC | None = ...,
        card_ogv: global___CardOGV | None = ...,
        card_article: global___CardArticle | None = ...,
        card_live: global___CardLive | None = ...,
        card_cheese: global___CardCheese | None = ...,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        viewAt: builtins.int = ...,
        kid: builtins.int = ...,
        oid: builtins.int = ...,
        business: builtins.str = ...,
        tp: builtins.int = ...,
        dt: global___DeviceType | None = ...,
        has_share: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["card_article", b"card_article", "card_cheese", b"card_cheese", "card_item", b"card_item", "card_live", b"card_live", "card_ogv", b"card_ogv", "card_ugc", b"card_ugc", "dt", b"dt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business", b"business", "card_article", b"card_article", "card_cheese", b"card_cheese", "card_item", b"card_item", "card_live", b"card_live", "card_ogv", b"card_ogv", "card_ugc", b"card_ugc", "dt", b"dt", "has_share", b"has_share", "kid", b"kid", "oid", b"oid", "title", b"title", "tp", b"tp", "uri", b"uri", "viewAt", b"viewAt"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["card_item", b"card_item"]) -> typing_extensions.Literal["card_ugc", "card_ogv", "card_article", "card_live", "card_cheese"] | None: ...

global___CursorItem = CursorItem

@typing_extensions.final
class CursorReply(google.protobuf.message.Message):
    """获取历史记录列表(旧版)-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    TAB_FIELD_NUMBER: builtins.int
    CURSOR_FIELD_NUMBER: builtins.int
    HASMORE_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CursorItem]:
        """卡片内容"""
    @property
    def tab(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CursorTab]:
        """顶部tab"""
    @property
    def cursor(self) -> global___Cursor:
        """游标信息"""
    hasMore: builtins.bool
    """是否未拉取完"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___CursorItem] | None = ...,
        tab: collections.abc.Iterable[global___CursorTab] | None = ...,
        cursor: global___Cursor | None = ...,
        hasMore: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor", b"cursor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor", b"cursor", "hasMore", b"hasMore", "items", b"items", "tab", b"tab"]) -> None: ...

global___CursorReply = CursorReply

@typing_extensions.final
class CursorReq(google.protobuf.message.Message):
    """获取历史记录列表(旧版)-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURSOR_FIELD_NUMBER: builtins.int
    BUSINESS_FIELD_NUMBER: builtins.int
    PLAYER_PRELOAD_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___Cursor:
        """游标信息"""
    business: builtins.str
    """业务类型
    all:全部 archive:视频 live:直播 article:专栏
    """
    @property
    def player_preload(self) -> global___PlayerPreloadParams:
        """秒开参数(旧版)"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
    def __init__(
        self,
        *,
        cursor: global___Cursor | None = ...,
        business: builtins.str = ...,
        player_preload: global___PlayerPreloadParams | None = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor", b"cursor", "player_args", b"player_args", "player_preload", b"player_preload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business", b"business", "cursor", b"cursor", "player_args", b"player_args", "player_preload", b"player_preload"]) -> None: ...

global___CursorReq = CursorReq

@typing_extensions.final
class CursorTab(google.protobuf.message.Message):
    """业务分类表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUSINESS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ROUTER_FIELD_NUMBER: builtins.int
    FOCUS_FIELD_NUMBER: builtins.int
    business: builtins.str
    """业务类型"""
    name: builtins.str
    """名称"""
    router: builtins.str
    """路由uri"""
    focus: builtins.bool
    """tab定位"""
    def __init__(
        self,
        *,
        business: builtins.str = ...,
        name: builtins.str = ...,
        router: builtins.str = ...,
        focus: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["business", b"business", "focus", b"focus", "name", b"name", "router", b"router"]) -> None: ...

global___CursorTab = CursorTab

@typing_extensions.final
class CursorV2Reply(google.protobuf.message.Message):
    """获取历史记录列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    CURSOR_FIELD_NUMBER: builtins.int
    HASMORE_FIELD_NUMBER: builtins.int
    EMPTY_LINK_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CursorItem]:
        """卡片内容"""
    @property
    def cursor(self) -> global___Cursor:
        """游标信息"""
    hasMore: builtins.bool
    """是否未拉取完"""
    empty_link: builtins.str
    """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___CursorItem] | None = ...,
        cursor: global___Cursor | None = ...,
        hasMore: builtins.bool = ...,
        empty_link: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor", b"cursor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor", b"cursor", "empty_link", b"empty_link", "hasMore", b"hasMore", "items", b"items"]) -> None: ...

global___CursorV2Reply = CursorV2Reply

@typing_extensions.final
class CursorV2Req(google.protobuf.message.Message):
    """获取历史记录列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURSOR_FIELD_NUMBER: builtins.int
    BUSINESS_FIELD_NUMBER: builtins.int
    PLAYER_PRELOAD_FIELD_NUMBER: builtins.int
    PLAYER_ARGS_FIELD_NUMBER: builtins.int
    IS_LOCAL_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___Cursor:
        """游标信息"""
    business: builtins.str
    """业务类型
    archive:视频 live:直播 article:专栏 goods:商品 show:展演
    """
    @property
    def player_preload(self) -> global___PlayerPreloadParams:
        """秒开参数(旧版)"""
    @property
    def player_args(self) -> bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs:
        """秒开参数"""
    is_local: builtins.bool
    """是否选择本机的播放历史"""
    def __init__(
        self,
        *,
        cursor: global___Cursor | None = ...,
        business: builtins.str = ...,
        player_preload: global___PlayerPreloadParams | None = ...,
        player_args: bilireq.grpc.protos.bilibili.app.archive.middleware.v1.preload_pb2.PlayerArgs | None = ...,
        is_local: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor", b"cursor", "player_args", b"player_args", "player_preload", b"player_preload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business", b"business", "cursor", b"cursor", "is_local", b"is_local", "player_args", b"player_args", "player_preload", b"player_preload"]) -> None: ...

global___CursorV2Req = CursorV2Req

@typing_extensions.final
class DeleteReq(google.protobuf.message.Message):
    """删除历史记录-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HIS_INFO_FIELD_NUMBER: builtins.int
    @property
    def his_info(self) -> global___HisInfo:
        """历史记录信息"""
    def __init__(
        self,
        *,
        his_info: global___HisInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["his_info", b"his_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["his_info", b"his_info"]) -> None: ...

global___DeleteReq = DeleteReq

@typing_extensions.final
class DeviceType(google.protobuf.message.Message):
    """设备类型"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    type: global___DT.ValueType
    """设备标识代码"""
    icon: builtins.str
    """图标url"""
    def __init__(
        self,
        *,
        type: global___DT.ValueType = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "type", b"type"]) -> None: ...

global___DeviceType = DeviceType

@typing_extensions.final
class HisInfo(google.protobuf.message.Message):
    """历史记录信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUSINESS_FIELD_NUMBER: builtins.int
    KID_FIELD_NUMBER: builtins.int
    business: builtins.str
    """业务类型
    archive:视频 live:直播 article:专栏 goods:商品 show:展演
    """
    kid: builtins.int
    """历史记录id"""
    def __init__(
        self,
        *,
        business: builtins.str = ...,
        kid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["business", b"business", "kid", b"kid"]) -> None: ...

global___HisInfo = HisInfo

@typing_extensions.final
class HistoryTabReply(google.protobuf.message.Message):
    """获取历史记录tab-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAB_FIELD_NUMBER: builtins.int
    @property
    def tab(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CursorTab]:
        """tab列表"""
    def __init__(
        self,
        *,
        tab: collections.abc.Iterable[global___CursorTab] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tab", b"tab"]) -> None: ...

global___HistoryTabReply = HistoryTabReply

@typing_extensions.final
class HistoryTabReq(google.protobuf.message.Message):
    """获取历史记录tab-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUSINESS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    business: builtins.str
    """业务类型
    archive:视频 live:直播 article:专栏 goods:商品 show:展演
    """
    source: global___HistorySource.ValueType
    """查询请求来源"""
    keyword: builtins.str
    """搜索关键词"""
    def __init__(
        self,
        *,
        business: builtins.str = ...,
        source: global___HistorySource.ValueType = ...,
        keyword: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["business", b"business", "keyword", b"keyword", "source", b"source"]) -> None: ...

global___HistoryTabReq = HistoryTabReq

@typing_extensions.final
class LatestHistoryReply(google.protobuf.message.Message):
    """获取最新的历史记录-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    RTIME_FIELD_NUMBER: builtins.int
    FLAG_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> global___CursorItem:
        """卡片内容"""
    scene: builtins.str
    """场景"""
    rtime: builtins.int
    """弹窗停留时间"""
    flag: builtins.str
    """分组的标志(客户端埋点上报)"""
    def __init__(
        self,
        *,
        items: global___CursorItem | None = ...,
        scene: builtins.str = ...,
        rtime: builtins.int = ...,
        flag: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["items", b"items"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["flag", b"flag", "items", b"items", "rtime", b"rtime", "scene", b"scene"]) -> None: ...

global___LatestHistoryReply = LatestHistoryReply

@typing_extensions.final
class LatestHistoryReq(google.protobuf.message.Message):
    """获取最新的历史记录-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUSINESS_FIELD_NUMBER: builtins.int
    PLAYER_PRELOAD_FIELD_NUMBER: builtins.int
    business: builtins.str
    """业务类型
    archive:视频 live:直播 article:专栏 goods:商品 show:展演
    """
    @property
    def player_preload(self) -> global___PlayerPreloadParams:
        """秒开参数"""
    def __init__(
        self,
        *,
        business: builtins.str = ...,
        player_preload: global___PlayerPreloadParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["player_preload", b"player_preload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business", b"business", "player_preload", b"player_preload"]) -> None: ...

global___LatestHistoryReq = LatestHistoryReq

@typing_extensions.final
class NoReply(google.protobuf.message.Message):
    """空响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoReply = NoReply

@typing_extensions.final
class Page(google.protobuf.message.Message):
    """页面信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PN_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    pn: builtins.int
    """当前页码"""
    total: builtins.int
    """总计条目数"""
    def __init__(
        self,
        *,
        pn: builtins.int = ...,
        total: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pn", b"pn", "total", b"total"]) -> None: ...

global___Page = Page

@typing_extensions.final
class PlayerPreloadParams(google.protobuf.message.Message):
    """秒开参数"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    FORCEHOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    qn: builtins.int
    """清晰度"""
    fnver: builtins.int
    """流版本"""
    fnval: builtins.int
    """流类型"""
    forceHost: builtins.int
    """是否强制域名"""
    fourk: builtins.int
    """是否4K"""
    def __init__(
        self,
        *,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        forceHost: builtins.int = ...,
        fourk: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fnval", b"fnval", "fnver", b"fnver", "forceHost", b"forceHost", "fourk", b"fourk", "qn", b"qn"]) -> None: ...

global___PlayerPreloadParams = PlayerPreloadParams

@typing_extensions.final
class Relation(google.protobuf.message.Message):
    """关系信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    IS_FOLLOW_FIELD_NUMBER: builtins.int
    IS_FOLLOWED_FIELD_NUMBER: builtins.int
    status: builtins.int
    """关系状态
    1:未关注 2:已关注 3:被关注 4:互关
    """
    is_follow: builtins.int
    """用户关注UP主"""
    is_followed: builtins.int
    """UP主关注用户"""
    def __init__(
        self,
        *,
        status: builtins.int = ...,
        is_follow: builtins.int = ...,
        is_followed: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_follow", b"is_follow", "is_followed", b"is_followed", "status", b"status"]) -> None: ...

global___Relation = Relation

@typing_extensions.final
class SearchReply(google.protobuf.message.Message):
    """搜索历史记录-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    HASMORE_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CursorItem]:
        """卡片内容"""
    hasMore: builtins.bool
    """是否未拉取完"""
    @property
    def page(self) -> global___Page:
        """页面信息"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___CursorItem] | None = ...,
        hasMore: builtins.bool = ...,
        page: global___Page | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["page", b"page"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hasMore", b"hasMore", "items", b"items", "page", b"page"]) -> None: ...

global___SearchReply = SearchReply

@typing_extensions.final
class SearchReq(google.protobuf.message.Message):
    """搜索历史记录-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYWORD_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    BUSINESS_FIELD_NUMBER: builtins.int
    keyword: builtins.str
    """关键词"""
    pn: builtins.int
    """页码"""
    business: builtins.str
    """业务类型
    archive:视频 live:直播 article:专栏 goods:商品 show:展演
    """
    def __init__(
        self,
        *,
        keyword: builtins.str = ...,
        pn: builtins.int = ...,
        business: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["business", b"business", "keyword", b"keyword", "pn", b"pn"]) -> None: ...

global___SearchReq = SearchReq



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/dagw/component/avatar/v1/avatar.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.dagw.component.avatar.common import common_pb2 as bilibili_dot_dagw_dot_component_dot_avatar_dot_common_dot_common__pb2
from bilireq.grpc.protos.bilibili.dagw.component.avatar.v1 import plugin_pb2 as bilibili_dot_dagw_dot_component_dot_avatar_dot_v1_dot_plugin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.bilibili/dagw/component/avatar/v1/avatar.proto\x12!bilibili.dagw.component.avatar.v1\x1a\x32\x62ilibili/dagw/component/avatar/common/common.proto\x1a.bilibili/dagw/component/avatar/v1/plugin.proto\"\xe9\x01\n\nAvatarItem\x12G\n\x0e\x63ontainer_size\x18\x01 \x01(\x0b\x32/.bilibili.dagw.component.avatar.common.SizeSpec\x12=\n\x06layers\x18\x02 \x03(\x0b\x32-.bilibili.dagw.component.avatar.v1.LayerGroup\x12\x46\n\x0f\x66\x61llback_layers\x18\x03 \x01(\x0b\x32-.bilibili.dagw.component.avatar.v1.LayerGroup\x12\x0b\n\x03mid\x18\x04 \x01(\x03\"\x8a\x02\n\x12\x42\x61sicLayerResource\x12\x10\n\x08res_type\x18\x01 \x01(\x05\x12@\n\tres_image\x18\x02 \x01(\x0b\x32+.bilibili.dagw.component.avatar.v1.ResImageH\x00\x12H\n\rres_animation\x18\x03 \x01(\x0b\x32/.bilibili.dagw.component.avatar.v1.ResAnimationH\x00\x12K\n\x0fres_native_draw\x18\x04 \x01(\x0b\x32\x30.bilibili.dagw.component.avatar.v1.ResNativeDrawH\x00\x42\t\n\x07payload\"\x9d\x01\n\rGeneralConfig\x12X\n\rweb_css_style\x18\x01 \x03(\x0b\x32\x41.bilibili.dagw.component.avatar.v1.GeneralConfig.WebCssStyleEntry\x1a\x32\n\x10WebCssStyleEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x02\n\x05Layer\x12\x10\n\x08layer_id\x18\x01 \x01(\t\x12\x0f\n\x07visible\x18\x02 \x01(\x08\x12M\n\x0cgeneral_spec\x18\x03 \x01(\x0b\x32\x37.bilibili.dagw.component.avatar.common.LayerGeneralSpec\x12\x44\n\x0clayer_config\x18\x04 \x01(\x0b\x32..bilibili.dagw.component.avatar.v1.LayerConfig\x12G\n\x08resource\x18\x05 \x01(\x0b\x32\x35.bilibili.dagw.component.avatar.v1.BasicLayerResource\"\xad\x02\n\x0bLayerConfig\x12\x46\n\x04tags\x18\x01 \x03(\x0b\x32\x38.bilibili.dagw.component.avatar.v1.LayerConfig.TagsEntry\x12\x13\n\x0bis_critical\x18\x02 \x01(\x08\x12\x18\n\x10\x61llow_over_paint\x18\x03 \x01(\x08\x12G\n\nlayer_mask\x18\x04 \x01(\x0b\x32\x33.bilibili.dagw.component.avatar.common.MaskProperty\x1a^\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12@\n\x05value\x18\x02 \x01(\x0b\x32\x31.bilibili.dagw.component.avatar.v1.LayerTagConfig:\x02\x38\x01\"\xbc\x01\n\nLayerGroup\x12\x10\n\x08group_id\x18\x01 \x01(\t\x12\x38\n\x06layers\x18\x02 \x03(\x0b\x32(.bilibili.dagw.component.avatar.v1.Layer\x12G\n\ngroup_mask\x18\x03 \x01(\x0b\x32\x33.bilibili.dagw.component.avatar.common.MaskProperty\x12\x19\n\x11is_critical_group\x18\x04 \x01(\x08\"\x8a\x03\n\x0eLayerTagConfig\x12\x13\n\x0b\x63onfig_type\x18\x01 \x01(\x05\x12J\n\x0egeneral_config\x18\x02 \x01(\x0b\x32\x30.bilibili.dagw.component.avatar.v1.GeneralConfigH\x00\x12K\n\x0bgyro_config\x18\x03 \x01(\x0b\x32\x34.bilibili.dagw.component.avatar.v1.plugin.GyroConfigH\x00\x12h\n\x1a\x63omment_doubleClick_config\x18\x04 \x01(\x0b\x32\x42.bilibili.dagw.component.avatar.v1.plugin.CommentDoubleClickConfigH\x00\x12V\n\x11live_anime_config\x18\x05 \x01(\x0b\x32\x39.bilibili.dagw.component.avatar.v1.plugin.LiveAnimeConfigH\x00\x42\x08\n\x06\x63onfig\"W\n\x0cResAnimation\x12G\n\x08webp_src\x18\x01 \x01(\x0b\x32\x35.bilibili.dagw.component.avatar.common.ResourceSource\"T\n\x08ResImage\x12H\n\timage_src\x18\x01 \x01(\x0b\x32\x35.bilibili.dagw.component.avatar.common.ResourceSource\"X\n\rResNativeDraw\x12G\n\x08\x64raw_src\x18\x01 \x01(\x0b\x32\x35.bilibili.dagw.component.avatar.common.ResourceSourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.dagw.component.avatar.v1.avatar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GENERALCONFIG_WEBCSSSTYLEENTRY._options = None
  _GENERALCONFIG_WEBCSSSTYLEENTRY._serialized_options = b'8\001'
  _LAYERCONFIG_TAGSENTRY._options = None
  _LAYERCONFIG_TAGSENTRY._serialized_options = b'8\001'
  _globals['_AVATARITEM']._serialized_start=186
  _globals['_AVATARITEM']._serialized_end=419
  _globals['_BASICLAYERRESOURCE']._serialized_start=422
  _globals['_BASICLAYERRESOURCE']._serialized_end=688
  _globals['_GENERALCONFIG']._serialized_start=691
  _globals['_GENERALCONFIG']._serialized_end=848
  _globals['_GENERALCONFIG_WEBCSSSTYLEENTRY']._serialized_start=798
  _globals['_GENERALCONFIG_WEBCSSSTYLEENTRY']._serialized_end=848
  _globals['_LAYER']._serialized_start=851
  _globals['_LAYER']._serialized_end=1115
  _globals['_LAYERCONFIG']._serialized_start=1118
  _globals['_LAYERCONFIG']._serialized_end=1419
  _globals['_LAYERCONFIG_TAGSENTRY']._serialized_start=1325
  _globals['_LAYERCONFIG_TAGSENTRY']._serialized_end=1419
  _globals['_LAYERGROUP']._serialized_start=1422
  _globals['_LAYERGROUP']._serialized_end=1610
  _globals['_LAYERTAGCONFIG']._serialized_start=1613
  _globals['_LAYERTAGCONFIG']._serialized_end=2007
  _globals['_RESANIMATION']._serialized_start=2009
  _globals['_RESANIMATION']._serialized_end=2096
  _globals['_RESIMAGE']._serialized_start=2098
  _globals['_RESIMAGE']._serialized_end=2182
  _globals['_RESNATIVEDRAW']._serialized_start=2184
  _globals['_RESNATIVEDRAW']._serialized_end=2272
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AnimateIcon(google.protobuf.message.Message):
    """动画效果"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    JSON_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """icon文件"""
    json: builtins.str
    """动效json文件"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        json: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "json", b"json"]) -> None: ...

global___AnimateIcon = AnimateIcon

@typing_extensions.final
class EntranceReply(google.protobuf.message.Message):
    """活动入口-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    ANIMATE_ICON_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """展示图标"""
    name: builtins.str
    """活动名称"""
    url: builtins.str
    """活动跳转链接"""
    @property
    def animate_icon(self) -> global___AnimateIcon:
        """动画效果"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        name: builtins.str = ...,
        url: builtins.str = ...,
        animate_icon: global___AnimateIcon | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["animate_icon", b"animate_icon"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["animate_icon", b"animate_icon", "icon", b"icon", "name", b"name", "url", b"url"]) -> None: ...

global___EntranceReply = EntranceReply

@typing_extensions.final
class EntranceReq(google.protobuf.message.Message):
    """活动入口-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EntranceReq = EntranceReq

@typing_extensions.final
class PrivacyReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___PrivacyReply = PrivacyReply

@typing_extensions.final
class PrivacyReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_UID_FIELD_NUMBER: builtins.int
    activity_uid: builtins.str
    """"""
    def __init__(
        self,
        *,
        activity_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_uid", b"activity_uid"]) -> None: ...

global___PrivacyReq = PrivacyReq

@typing_extensions.final
class WindowReply(google.protobuf.message.Message):
    """首页弹窗-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    REPORT_DATA_FIELD_NUMBER: builtins.int
    type: builtins.int
    """弹窗类型
    0:弹窗 1:普通页面
    """
    url: builtins.str
    """跳转链接"""
    report_data: builtins.str
    """上报数据字段"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        url: builtins.str = ...,
        report_data: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["report_data", b"report_data", "type", b"type", "url", b"url"]) -> None: ...

global___WindowReply = WindowReply

@typing_extensions.final
class WindowReq(google.protobuf.message.Message):
    """首页弹窗-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___WindowReq = WindowReq



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/live/app/room/v1/room.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$bilibili/live/app/room/v1/room.proto\x12\x19\x62ilibili.live.app.room.v1\"#\n\x10GetStudioListReq\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\"\x86\x04\n\x11GetStudioListResp\x12\x0e\n\x06status\x18\x01 \x01(\x03\x12N\n\x0bmaster_list\x18\x02 \x03(\x0b\x32\x39.bilibili.live.app.room.v1.GetStudioListResp.StudioMaster\x1a\x94\x01\n\x08Pendants\x12\x43\n\x05\x66rame\x18\x01 \x01(\x0b\x32\x34.bilibili.live.app.room.v1.GetStudioListResp.Pendant\x12\x43\n\x05\x62\x61\x64ge\x18\x02 \x01(\x0b\x32\x34.bilibili.live.app.room.v1.GetStudioListResp.Pendant\x1a\x46\n\x07Pendant\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08position\x18\x02 \x01(\x03\x12\r\n\x05value\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x1a\xb1\x01\n\x0cStudioMaster\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\r\n\x05uname\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12G\n\x08pendants\x18\x05 \x01(\x0b\x32\x35.bilibili.live.app.room.v1.GetStudioListResp.Pendants\x12\x0b\n\x03tag\x18\x06 \x01(\t\x12\x10\n\x08tag_type\x18\x07 \x01(\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.live.app.room.v1.room_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETSTUDIOLISTREQ']._serialized_start=67
  _globals['_GETSTUDIOLISTREQ']._serialized_end=102
  _globals['_GETSTUDIOLISTRESP']._serialized_start=105
  _globals['_GETSTUDIOLISTRESP']._serialized_end=623
  _globals['_GETSTUDIOLISTRESP_PENDANTS']._serialized_start=223
  _globals['_GETSTUDIOLISTRESP_PENDANTS']._serialized_end=371
  _globals['_GETSTUDIOLISTRESP_PENDANT']._serialized_start=373
  _globals['_GETSTUDIOLISTRESP_PENDANT']._serialized_end=443
  _globals['_GETSTUDIOLISTRESP_STUDIOMASTER']._serialized_start=446
  _globals['_GETSTUDIOLISTRESP_STUDIOMASTER']._serialized_end=623
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.interfaces.v1 import media_pb2 as bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2


class MediaStub(object):
    """
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.MediaTab = channel.unary_unary(
                '/bilibili.app.interface.v1.Media/MediaTab',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaTabReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaTabReply.FromString,
                )
        self.MediaDetail = channel.unary_unary(
                '/bilibili.app.interface.v1.Media/MediaDetail',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaDetailReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaDetailReply.FromString,
                )
        self.MediaVideo = channel.unary_unary(
                '/bilibili.app.interface.v1.Media/MediaVideo',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaVideoReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaVideoReply.FromString,
                )
        self.MediaRelation = channel.unary_unary(
                '/bilibili.app.interface.v1.Media/MediaRelation',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaRelationReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaRelationReply.FromString,
                )
        self.MediaFollow = channel.unary_unary(
                '/bilibili.app.interface.v1.Media/MediaFollow',
                request_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaFollowReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaFollowReply.FromString,
                )


class MediaServicer(object):
    """
    """

    def MediaTab(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MediaDetail(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MediaVideo(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MediaRelation(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MediaFollow(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MediaServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'MediaTab': grpc.unary_unary_rpc_method_handler(
                    servicer.MediaTab,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaTabReq.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaTabReply.SerializeToString,
            ),
            'MediaDetail': grpc.unary_unary_rpc_method_handler(
                    servicer.MediaDetail,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaDetailReq.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaDetailReply.SerializeToString,
            ),
            'MediaVideo': grpc.unary_unary_rpc_method_handler(
                    servicer.MediaVideo,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaVideoReq.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaVideoReply.SerializeToString,
            ),
            'MediaRelation': grpc.unary_unary_rpc_method_handler(
                    servicer.MediaRelation,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaRelationReq.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaRelationReply.SerializeToString,
            ),
            'MediaFollow': grpc.unary_unary_rpc_method_handler(
                    servicer.MediaFollow,
                    request_deserializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaFollowReq.FromString,
                    response_serializer=bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaFollowReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.interface.v1.Media', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Media(object):
    """
    """

    @staticmethod
    def MediaTab(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interface.v1.Media/MediaTab',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaTabReq.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaTabReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MediaDetail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interface.v1.Media/MediaDetail',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaDetailReq.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaDetailReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MediaVideo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interface.v1.Media/MediaVideo',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaVideoReq.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaVideoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MediaRelation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interface.v1.Media/MediaRelation',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaRelationReq.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaRelationReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MediaFollow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.interface.v1.Media/MediaFollow',
            bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaFollowReq.SerializeToString,
            bilibili_dot_app_dot_interfaces_dot_v1_dot_media__pb2.MediaFollowReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/broadcast/message/main/dm.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/broadcast/message/main/dm.proto\x12\x1f\x62ilibili.broadcast.message.main\"K\n\x0c\x44\x61nmukuEvent\x12;\n\x05\x65lems\x18\x01 \x03(\x0b\x32,.bilibili.broadcast.message.main.DanmakuElem\"\xba\x01\n\x0b\x44\x61nmakuElem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08progress\x18\x02 \x01(\x05\x12\x0c\n\x04mode\x18\x03 \x01(\x05\x12\x10\n\x08\x66ontsize\x18\x04 \x01(\x05\x12\r\n\x05\x63olor\x18\x05 \x01(\r\x12\x10\n\x08mid_hash\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\r\n\x05\x63time\x18\x08 \x01(\x03\x12\x0e\n\x06\x61\x63tion\x18\t \x01(\t\x12\x0c\n\x04pool\x18\n \x01(\x05\x12\x0e\n\x06id_str\x18\x0b \x01(\t\"\xbe\x01\n\tCommandDm\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x05 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\x05\x12\x10\n\x08progress\x18\x08 \x01(\x05\x12\r\n\x05\x63time\x18\t \x01(\t\x12\r\n\x05mtime\x18\n \x01(\t\x12\r\n\x05\x65xtra\x18\x0b \x01(\t\x12\r\n\x05idStr\x18\x0c \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.message.main.dm_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DANMUKUEVENT']._serialized_start=77
  _globals['_DANMUKUEVENT']._serialized_end=152
  _globals['_DANMAKUELEM']._serialized_start=155
  _globals['_DANMAKUELEM']._serialized_end=341
  _globals['_COMMANDDM']._serialized_start=344
  _globals['_COMMANDDM']._serialized_end=534
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.card.v1.single_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Card(google.protobuf.message.Message):
    """卡片信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SMALL_COVER_V5_FIELD_NUMBER: builtins.int
    LARGE_COVER_V1_FIELD_NUMBER: builtins.int
    THREE_ITEM_ALL_V2_FIELD_NUMBER: builtins.int
    THREE_ITEM_V1_FIELD_NUMBER: builtins.int
    HOT_TOPIC_FIELD_NUMBER: builtins.int
    THREE_ITEM_H_V5_FIELD_NUMBER: builtins.int
    MIDDLE_COVER_V3_FIELD_NUMBER: builtins.int
    LARGE_COVER_V4_FIELD_NUMBER: builtins.int
    POPULAR_TOP_ENTRANCE_FIELD_NUMBER: builtins.int
    RCMD_ONE_ITEM_FIELD_NUMBER: builtins.int
    SMALL_COVER_V5_AD_FIELD_NUMBER: builtins.int
    @property
    def small_cover_v5(self) -> bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.SmallCoverV5:
        """小封面条目"""
    @property
    def large_cover_v1(self) -> bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.LargeCoverV1:
        """"""
    @property
    def three_item_all_v2(self) -> bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.ThreeItemAllV2:
        """"""
    @property
    def three_item_v1(self) -> bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.ThreeItemV1:
        """"""
    @property
    def hot_topic(self) -> bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.HotTopic:
        """"""
    @property
    def three_item_h_v5(self) -> bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.DynamicHot:
        """"""
    @property
    def middle_cover_v3(self) -> bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.MiddleCoverV3:
        """"""
    @property
    def large_cover_v4(self) -> bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.LargeCoverV4:
        """"""
    @property
    def popular_top_entrance(self) -> bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.PopularTopEntrance:
        """热门列表顶部按钮"""
    @property
    def rcmd_one_item(self) -> bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.RcmdOneItem:
        """"""
    @property
    def small_cover_v5_ad(self) -> bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.SmallCoverV5Ad:
        """"""
    def __init__(
        self,
        *,
        small_cover_v5: bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.SmallCoverV5 | None = ...,
        large_cover_v1: bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.LargeCoverV1 | None = ...,
        three_item_all_v2: bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.ThreeItemAllV2 | None = ...,
        three_item_v1: bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.ThreeItemV1 | None = ...,
        hot_topic: bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.HotTopic | None = ...,
        three_item_h_v5: bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.DynamicHot | None = ...,
        middle_cover_v3: bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.MiddleCoverV3 | None = ...,
        large_cover_v4: bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.LargeCoverV4 | None = ...,
        popular_top_entrance: bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.PopularTopEntrance | None = ...,
        rcmd_one_item: bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.RcmdOneItem | None = ...,
        small_cover_v5_ad: bilireq.grpc.protos.bilibili.app.card.v1.single_pb2.SmallCoverV5Ad | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hot_topic", b"hot_topic", "item", b"item", "large_cover_v1", b"large_cover_v1", "large_cover_v4", b"large_cover_v4", "middle_cover_v3", b"middle_cover_v3", "popular_top_entrance", b"popular_top_entrance", "rcmd_one_item", b"rcmd_one_item", "small_cover_v5", b"small_cover_v5", "small_cover_v5_ad", b"small_cover_v5_ad", "three_item_all_v2", b"three_item_all_v2", "three_item_h_v5", b"three_item_h_v5", "three_item_v1", b"three_item_v1"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hot_topic", b"hot_topic", "item", b"item", "large_cover_v1", b"large_cover_v1", "large_cover_v4", b"large_cover_v4", "middle_cover_v3", b"middle_cover_v3", "popular_top_entrance", b"popular_top_entrance", "rcmd_one_item", b"rcmd_one_item", "small_cover_v5", b"small_cover_v5", "small_cover_v5_ad", b"small_cover_v5_ad", "three_item_all_v2", b"three_item_all_v2", "three_item_h_v5", b"three_item_h_v5", "three_item_v1", b"three_item_v1"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item", b"item"]) -> typing_extensions.Literal["small_cover_v5", "large_cover_v1", "three_item_all_v2", "three_item_v1", "hot_topic", "three_item_h_v5", "middle_cover_v3", "large_cover_v4", "popular_top_entrance", "rcmd_one_item", "small_cover_v5_ad"] | None: ...

global___Card = Card



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/app/search/v2/search.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.broadcast.message.main import search_pb2 as bilibili_dot_broadcast_dot_message_dot_main_dot_search__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#bilibili/app/search/v2/search.proto\x12\x16\x62ilibili.app.search.v2\x1a,bilibili/broadcast/message/main/search.proto\"<\n\x11\x43\x61ncelChatTaskReq\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66rom_source\x18\x02 \x01(\t\"#\n\x13\x43\x61ncelChatTaskReply\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\"J\n\x10GetChatResultReq\x12\r\n\x05query\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x13\n\x0b\x66rom_source\x18\x03 \x01(\t\"\xf2\x01\n\rSearchEggInfo\x12\x10\n\x08\x65gg_type\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x15\n\ris_commercial\x18\x03 \x01(\x05\x12\x12\n\nmask_color\x18\x04 \x01(\t\x12\x19\n\x11mask_transparency\x18\x05 \x01(\x03\x12\x0b\n\x03md5\x18\x06 \x01(\t\x12\x0f\n\x07re_type\x18\x07 \x01(\x05\x12\x0e\n\x06re_url\x18\x08 \x01(\t\x12\x10\n\x08re_value\x18\t \x01(\t\x12\x12\n\nshow_count\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x03\x12\x0e\n\x06source\x18\x0c \x01(\x03\x12\x0b\n\x03url\x18\r \x01(\t\"I\n\x0eSearchEggInfos\x12\x37\n\x08\x65gg_info\x18\x01 \x03(\x0b\x32%.bilibili.app.search.v2.SearchEggInfo\"d\n\x0eSearchEggReply\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0c\n\x04seid\x18\x02 \x01(\t\x12\x36\n\x06result\x18\x03 \x01(\x0b\x32&.bilibili.app.search.v2.SearchEggInfos\"\x0e\n\x0cSearchEggReq\"7\n\x13SubmitChatTaskReply\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x12\n\nsession_id\x18\x02 \x01(\t\"I\n\x11SubmitChatTaskReq\x12\r\n\x05query\x18\x01 \x01(\t\x12\x10\n\x08track_id\x18\x02 \x01(\t\x12\x13\n\x0b\x66rom_source\x18\x03 \x01(\t2\x9f\x03\n\x06Search\x12h\n\x0e\x43\x61ncelChatTask\x12).bilibili.app.search.v2.CancelChatTaskReq\x1a+.bilibili.app.search.v2.CancelChatTaskReply\x12\x66\n\rGetChatResult\x12(.bilibili.app.search.v2.GetChatResultReq\x1a+.bilibili.broadcast.message.main.ChatResult\x12Y\n\tSearchEgg\x12$.bilibili.app.search.v2.SearchEggReq\x1a&.bilibili.app.search.v2.SearchEggReply\x12h\n\x0eSubmitChatTask\x12).bilibili.app.search.v2.SubmitChatTaskReq\x1a+.bilibili.app.search.v2.SubmitChatTaskReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.search.v2.search_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CANCELCHATTASKREQ']._serialized_start=109
  _globals['_CANCELCHATTASKREQ']._serialized_end=169
  _globals['_CANCELCHATTASKREPLY']._serialized_start=171
  _globals['_CANCELCHATTASKREPLY']._serialized_end=206
  _globals['_GETCHATRESULTREQ']._serialized_start=208
  _globals['_GETCHATRESULTREQ']._serialized_end=282
  _globals['_SEARCHEGGINFO']._serialized_start=285
  _globals['_SEARCHEGGINFO']._serialized_end=527
  _globals['_SEARCHEGGINFOS']._serialized_start=529
  _globals['_SEARCHEGGINFOS']._serialized_end=602
  _globals['_SEARCHEGGREPLY']._serialized_start=604
  _globals['_SEARCHEGGREPLY']._serialized_end=704
  _globals['_SEARCHEGGREQ']._serialized_start=706
  _globals['_SEARCHEGGREQ']._serialized_end=720
  _globals['_SUBMITCHATTASKREPLY']._serialized_start=722
  _globals['_SUBMITCHATTASKREPLY']._serialized_end=777
  _globals['_SUBMITCHATTASKREQ']._serialized_start=779
  _globals['_SUBMITCHATTASKREQ']._serialized_end=852
  _globals['_SEARCH']._serialized_start=855
  _globals['_SEARCH']._serialized_end=1270
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/broadcast/message/ogv/live.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)bilibili/broadcast/message/ogv/live.proto\x12\x1e\x62ilibili.broadcast.message.ogv\"\x10\n\x0eLiveStartEvent\"\x0e\n\x0cLiveEndEvent\"!\n\x0fLiveOnlineEvent\x12\x0e\n\x06online\x18\x01 \x01(\x03\"`\n\x0fLiveUpdateEvent\x12\x1b\n\x13\x61\x66ter_premiere_type\x18\x01 \x01(\x05\x12\x12\n\nstart_time\x18\x02 \x01(\x03\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08progress\x18\x04 \x01(\x03\"\x9c\x02\n\x07\x43MDBody\x12?\n\x05start\x18\x01 \x01(\x0b\x32..bilibili.broadcast.message.ogv.LiveStartEventH\x00\x12\x41\n\temergency\x18\x02 \x01(\x0b\x32,.bilibili.broadcast.message.ogv.LiveEndEventH\x00\x12\x41\n\x06online\x18\x03 \x01(\x0b\x32/.bilibili.broadcast.message.ogv.LiveOnlineEventH\x00\x12\x41\n\x06update\x18\x04 \x01(\x0b\x32/.bilibili.broadcast.message.ogv.LiveUpdateEventH\x00\x42\x07\n\x05\x65ventb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.message.ogv.live_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LIVESTARTEVENT']._serialized_start=77
  _globals['_LIVESTARTEVENT']._serialized_end=93
  _globals['_LIVEENDEVENT']._serialized_start=95
  _globals['_LIVEENDEVENT']._serialized_end=109
  _globals['_LIVEONLINEEVENT']._serialized_start=111
  _globals['_LIVEONLINEEVENT']._serialized_end=144
  _globals['_LIVEUPDATEEVENT']._serialized_start=146
  _globals['_LIVEUPDATEEVENT']._serialized_end=242
  _globals['_CMDBODY']._serialized_start=245
  _globals['_CMDBODY']._serialized_end=529
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/tv/interfaces/dm/v1/dm.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/tv/interfaces/dm/v1/dm.proto\x12\x1c\x62ilibili.tv.interfaces.dm.v1\"2\n\x07\x43hronos\x12\x0b\n\x03md5\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\x0c\n\x04sign\x18\x03 \x01(\t\"\xb2\x01\n\tCommandDm\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\x12\x10\n\x08progress\x18\x06 \x01(\x05\x12\r\n\x05\x63time\x18\x07 \x01(\t\x12\r\n\x05mtime\x18\x08 \x01(\t\x12\r\n\x05\x65xtra\x18\t \x01(\t\x12\r\n\x05idStr\x18\n \x01(\t\x12\x0f\n\x07\x64isplay\x18\x0b \x01(\x03\"\xc2\x01\n\x0c\x43ommandDmOtt\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x05 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\x05\x12\x10\n\x08progress\x18\x08 \x01(\x05\x12\r\n\x05\x63time\x18\t \x01(\t\x12\r\n\x05mtime\x18\n \x01(\t\x12\r\n\x05\x65xtra\x18\x0b \x01(\t\x12\x0e\n\x06id_str\x18\x0c \x01(\t\"Y\n\x12\x43ommandDmsOttReply\x12\x43\n\x0f\x63ommand_dms_ott\x18\x01 \x03(\x0b\x32*.bilibili.tv.interfaces.dm.v1.CommandDmOtt\"9\n\x10\x43ommandDmsOttReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\x03\"L\n\rDanmakuAIFlag\x12;\n\x08\x64m_flags\x18\x01 \x03(\x0b\x32).bilibili.tv.interfaces.dm.v1.DanmakuFlag\"\xd6\x01\n\x0b\x44\x61nmakuElem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08progress\x18\x02 \x01(\x05\x12\x0c\n\x04mode\x18\x03 \x01(\x05\x12\x10\n\x08\x66ontsize\x18\x04 \x01(\x05\x12\r\n\x05\x63olor\x18\x05 \x01(\r\x12\x0f\n\x07midHash\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\r\n\x05\x63time\x18\x08 \x01(\x03\x12\x0e\n\x06weight\x18\t \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\n \x01(\t\x12\x0c\n\x04pool\x18\x0b \x01(\x05\x12\r\n\x05idStr\x18\x0c \x01(\t\x12\x0c\n\x04\x61ttr\x18\r \x01(\x05\")\n\x0b\x44\x61nmakuFlag\x12\x0c\n\x04\x64mid\x18\x01 \x01(\x03\x12\x0c\n\x04\x66lag\x18\x02 \x01(\r\"K\n\x11\x44\x61nmakuFlagConfig\x12\x10\n\x08rec_flag\x18\x01 \x01(\x05\x12\x10\n\x08rec_text\x18\x02 \x01(\t\x12\x12\n\nrec_switch\x18\x03 \x01(\x05\"\xcc\x04\n\x18\x44\x61nmuDefaultPlayerConfig\x12)\n!player_danmaku_use_default_config\x18\x01 \x01(\x08\x12,\n$player_danmaku_ai_recommended_switch\x18\x04 \x01(\x08\x12+\n#player_danmaku_ai_recommended_level\x18\x05 \x01(\x05\x12\x1f\n\x17player_danmaku_blocktop\x18\x06 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockscroll\x18\x07 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockbottom\x18\x08 \x01(\x08\x12$\n\x1cplayer_danmaku_blockcolorful\x18\t \x01(\x08\x12\"\n\x1aplayer_danmaku_blockrepeat\x18\n \x01(\x08\x12#\n\x1bplayer_danmaku_blockspecial\x18\x0b \x01(\x08\x12\x1e\n\x16player_danmaku_opacity\x18\x0c \x01(\x02\x12$\n\x1cplayer_danmaku_scalingfactor\x18\r \x01(\x02\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\x12\x1c\n\x14player_danmaku_speed\x18\x0f \x01(\x05\x12$\n\x1cinline_player_danmaku_switch\x18\x10 \x01(\x08\x12)\n!player_danmaku_senior_mode_switch\x18\x11 \x01(\x05\"\xd3\x05\n\x11\x44\x61nmuPlayerConfig\x12\x1d\n\x15player_danmaku_switch\x18\x01 \x01(\x08\x12\"\n\x1aplayer_danmaku_switch_save\x18\x02 \x01(\x08\x12)\n!player_danmaku_use_default_config\x18\x03 \x01(\x08\x12,\n$player_danmaku_ai_recommended_switch\x18\x04 \x01(\x08\x12+\n#player_danmaku_ai_recommended_level\x18\x05 \x01(\x05\x12\x1f\n\x17player_danmaku_blocktop\x18\x06 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockscroll\x18\x07 \x01(\x08\x12\"\n\x1aplayer_danmaku_blockbottom\x18\x08 \x01(\x08\x12$\n\x1cplayer_danmaku_blockcolorful\x18\t \x01(\x08\x12\"\n\x1aplayer_danmaku_blockrepeat\x18\n \x01(\x08\x12#\n\x1bplayer_danmaku_blockspecial\x18\x0b \x01(\x08\x12\x1e\n\x16player_danmaku_opacity\x18\x0c \x01(\x02\x12$\n\x1cplayer_danmaku_scalingfactor\x18\r \x01(\x02\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\x12\x1c\n\x14player_danmaku_speed\x18\x0f \x01(\x05\x12&\n\x1eplayer_danmaku_enableblocklist\x18\x10 \x01(\x08\x12$\n\x1cinline_player_danmaku_switch\x18\x11 \x01(\x08\x12$\n\x1cinline_player_danmaku_config\x18\x12 \x01(\x05\x12&\n\x1eplayer_danmaku_ios_switch_save\x18\x13 \x01(\x05\"K\n\x18\x44\x61nmuPlayerDynamicConfig\x12\x10\n\x08progress\x18\x01 \x01(\x05\x12\x1d\n\x15player_danmaku_domain\x18\x0e \x01(\x02\"\xa5\x02\n\x15\x44\x61nmuPlayerViewConfig\x12]\n\x1d\x64\x61nmuku_default_player_config\x18\x01 \x01(\x0b\x32\x36.bilibili.tv.interfaces.dm.v1.DanmuDefaultPlayerConfig\x12N\n\x15\x64\x61nmuku_player_config\x18\x02 \x01(\x0b\x32/.bilibili.tv.interfaces.dm.v1.DanmuPlayerConfig\x12]\n\x1d\x64\x61nmuku_player_dynamic_config\x18\x03 \x03(\x0b\x32\x36.bilibili.tv.interfaces.dm.v1.DanmuPlayerDynamicConfig\"\x99\x01\n\x10\x44mSegMobileReply\x12\x38\n\x05\x65lems\x18\x01 \x03(\x0b\x32).bilibili.tv.interfaces.dm.v1.DanmakuElem\x12\r\n\x05state\x18\x02 \x01(\x05\x12<\n\x07\x61i_flag\x18\x03 \x01(\x0b\x32+.bilibili.tv.interfaces.dm.v1.DanmakuAIFlag\"u\n\x0e\x44mSegMobileReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x15\n\rsegment_index\x18\x04 \x01(\x03\x12\x16\n\x0eteenagers_mode\x18\x05 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x06 \x01(\x03\"\xd8\x03\n\x0b\x44mViewReply\x12\x0e\n\x06\x63losed\x18\x01 \x01(\x08\x12\x35\n\x04mask\x18\x02 \x01(\x0b\x32\'.bilibili.tv.interfaces.dm.v1.VideoMask\x12=\n\x08subtitle\x18\x03 \x01(\x0b\x32+.bilibili.tv.interfaces.dm.v1.VideoSubtitle\x12\x13\n\x0bspecial_dms\x18\x04 \x03(\t\x12@\n\x07\x61i_flag\x18\x05 \x01(\x0b\x32/.bilibili.tv.interfaces.dm.v1.DanmakuFlagConfig\x12J\n\rplayer_config\x18\x06 \x01(\x0b\x32\x33.bilibili.tv.interfaces.dm.v1.DanmuPlayerViewConfig\x12\x16\n\x0esend_box_style\x18\x07 \x01(\x05\x12\r\n\x05\x61llow\x18\x08 \x01(\x08\x12\x11\n\tcheck_box\x18\t \x01(\t\x12\x1a\n\x12\x63heck_box_show_msg\x18\n \x01(\t\x12\x18\n\x10text_placeholder\x18\x0b \x01(\t\x12\x19\n\x11input_placeholder\x18\x0c \x01(\t\x12\x15\n\rcommand_close\x18\r \x01(\x08\"f\n\tDmViewReq\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\r\n\x05spmid\x18\x04 \x01(\t\x12\x14\n\x0cis_hard_boot\x18\x05 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x06 \x01(\x03\"\x96\x01\n\x0cSubtitleItem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0e\n\x06id_str\x18\x02 \x01(\t\x12\x0b\n\x03lan\x18\x03 \x01(\t\x12\x0f\n\x07lan_doc\x18\x04 \x01(\t\x12\x14\n\x0csubtitle_url\x18\x05 \x01(\t\x12\x36\n\x06\x61uthor\x18\x06 \x01(\x0b\x32&.bilibili.tv.interfaces.dm.v1.UserInfo\"\x8c\x01\n\x13TvViewProgressReply\x12=\n\x0bvideo_guide\x18\x01 \x01(\x0b\x32(.bilibili.tv.interfaces.dm.v1.VideoGuide\x12\x36\n\x07\x63hronos\x18\x02 \x01(\x0b\x32%.bilibili.tv.interfaces.dm.v1.Chronos\"\xd4\x01\n\x11TvViewProgressReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\x0e\n\x06up_mid\x18\x03 \x01(\x03\x12\x16\n\x0e\x65ngine_version\x18\x04 \x01(\t\x12\x18\n\x10message_protocol\x18\x05 \x01(\t\x12\x13\n\x0bservice_key\x18\x06 \x01(\t\x12\x0b\n\x03sid\x18\x07 \x01(\x03\x12\x0b\n\x03pid\x18\x08 \x01(\x03\x12\x0c\n\x04\x66rom\x18\t \x01(\x03\x12\x18\n\x10guest_access_key\x18\n \x01(\t\x12\x0c\n\x04\x65pid\x18\x0b \x01(\x03\"\\\n\x08UserInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03sex\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x04 \x01(\t\x12\x0c\n\x04sign\x18\x05 \x01(\t\x12\x0c\n\x04rank\x18\x06 \x01(\x05\"J\n\nVideoGuide\x12<\n\x0b\x63ommand_dms\x18\x02 \x03(\x0b\x32\'.bilibili.tv.interfaces.dm.v1.CommandDm\"S\n\tVideoMask\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x12\x0c\n\x04plat\x18\x02 \x01(\x05\x12\x0b\n\x03\x66ps\x18\x03 \x01(\x05\x12\x0c\n\x04time\x18\x04 \x01(\x03\x12\x10\n\x08mask_url\x18\x05 \x01(\t\"k\n\rVideoSubtitle\x12\x0b\n\x03lan\x18\x01 \x01(\t\x12\x0e\n\x06lanDoc\x18\x02 \x01(\t\x12=\n\tsubtitles\x18\x03 \x03(\x0b\x32*.bilibili.tv.interfaces.dm.v1.SubtitleItemb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.tv.interfaces.dm.v1.dm_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CHRONOS']._serialized_start=71
  _globals['_CHRONOS']._serialized_end=121
  _globals['_COMMANDDM']._serialized_start=124
  _globals['_COMMANDDM']._serialized_end=302
  _globals['_COMMANDDMOTT']._serialized_start=305
  _globals['_COMMANDDMOTT']._serialized_end=499
  _globals['_COMMANDDMSOTTREPLY']._serialized_start=501
  _globals['_COMMANDDMSOTTREPLY']._serialized_end=590
  _globals['_COMMANDDMSOTTREQ']._serialized_start=592
  _globals['_COMMANDDMSOTTREQ']._serialized_end=649
  _globals['_DANMAKUAIFLAG']._serialized_start=651
  _globals['_DANMAKUAIFLAG']._serialized_end=727
  _globals['_DANMAKUELEM']._serialized_start=730
  _globals['_DANMAKUELEM']._serialized_end=944
  _globals['_DANMAKUFLAG']._serialized_start=946
  _globals['_DANMAKUFLAG']._serialized_end=987
  _globals['_DANMAKUFLAGCONFIG']._serialized_start=989
  _globals['_DANMAKUFLAGCONFIG']._serialized_end=1064
  _globals['_DANMUDEFAULTPLAYERCONFIG']._serialized_start=1067
  _globals['_DANMUDEFAULTPLAYERCONFIG']._serialized_end=1655
  _globals['_DANMUPLAYERCONFIG']._serialized_start=1658
  _globals['_DANMUPLAYERCONFIG']._serialized_end=2381
  _globals['_DANMUPLAYERDYNAMICCONFIG']._serialized_start=2383
  _globals['_DANMUPLAYERDYNAMICCONFIG']._serialized_end=2458
  _globals['_DANMUPLAYERVIEWCONFIG']._serialized_start=2461
  _globals['_DANMUPLAYERVIEWCONFIG']._serialized_end=2754
  _globals['_DMSEGMOBILEREPLY']._serialized_start=2757
  _globals['_DMSEGMOBILEREPLY']._serialized_end=2910
  _globals['_DMSEGMOBILEREQ']._serialized_start=2912
  _globals['_DMSEGMOBILEREQ']._serialized_end=3029
  _globals['_DMVIEWREPLY']._serialized_start=3032
  _globals['_DMVIEWREPLY']._serialized_end=3504
  _globals['_DMVIEWREQ']._serialized_start=3506
  _globals['_DMVIEWREQ']._serialized_end=3608
  _globals['_SUBTITLEITEM']._serialized_start=3611
  _globals['_SUBTITLEITEM']._serialized_end=3761
  _globals['_TVVIEWPROGRESSREPLY']._serialized_start=3764
  _globals['_TVVIEWPROGRESSREPLY']._serialized_end=3904
  _globals['_TVVIEWPROGRESSREQ']._serialized_start=3907
  _globals['_TVVIEWPROGRESSREQ']._serialized_end=4119
  _globals['_USERINFO']._serialized_start=4121
  _globals['_USERINFO']._serialized_end=4213
  _globals['_VIDEOGUIDE']._serialized_start=4215
  _globals['_VIDEOGUIDE']._serialized_end=4289
  _globals['_VIDEOMASK']._serialized_start=4291
  _globals['_VIDEOMASK']._serialized_end=4374
  _globals['_VIDEOSUBTITLE']._serialized_start=4376
  _globals['_VIDEOSUBTITLE']._serialized_end=4483
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class OtherSettingsConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WATERMARK_TYPE_FIELD_NUMBER: builtins.int
    WEB_IMAGE_QUALITY_TYPE_FIELD_NUMBER: builtins.int
    ENABLE_READ_PASTEBOARD_FIELD_NUMBER: builtins.int
    PASTE_AUTO_JUMP_FIELD_NUMBER: builtins.int
    MINI_SCREEN_PLAY_WHEN_BACK_FIELD_NUMBER: builtins.int
    ENABLE_RESUME_PLAYING_FIELD_NUMBER: builtins.int
    ENABLE_WIFI_AUTO_UPDATE_FIELD_NUMBER: builtins.int
    ENABLE_GUIDE_SCREENSHOT_SHARE_FIELD_NUMBER: builtins.int
    @property
    def watermark_type(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def web_image_quality_type(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value:
        """"""
    @property
    def enable_read_pasteboard(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def paste_auto_jump(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def mini_screen_play_when_back(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_resume_playing(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_wifi_auto_update(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    @property
    def enable_guide_screenshot_share(self) -> bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue:
        """"""
    def __init__(
        self,
        *,
        watermark_type: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        web_image_quality_type: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.Int64Value | None = ...,
        enable_read_pasteboard: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        paste_auto_jump: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        mini_screen_play_when_back: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_resume_playing: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_wifi_auto_update: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
        enable_guide_screenshot_share: bilireq.grpc.protos.bilibili.app.distribution.v1.distribution_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["enable_guide_screenshot_share", b"enable_guide_screenshot_share", "enable_read_pasteboard", b"enable_read_pasteboard", "enable_resume_playing", b"enable_resume_playing", "enable_wifi_auto_update", b"enable_wifi_auto_update", "mini_screen_play_when_back", b"mini_screen_play_when_back", "paste_auto_jump", b"paste_auto_jump", "watermark_type", b"watermark_type", "web_image_quality_type", b"web_image_quality_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_guide_screenshot_share", b"enable_guide_screenshot_share", "enable_read_pasteboard", b"enable_read_pasteboard", "enable_resume_playing", b"enable_resume_playing", "enable_wifi_auto_update", b"enable_wifi_auto_update", "mini_screen_play_when_back", b"mini_screen_play_when_back", "paste_auto_jump", b"paste_auto_jump", "watermark_type", b"watermark_type", "web_image_quality_type", b"web_image_quality_type"]) -> None: ...

global___OtherSettingsConfig = OtherSettingsConfig



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.search.v2 import search_pb2 as bilibili_dot_app_dot_search_dot_v2_dot_search__pb2
from bilireq.grpc.protos.bilibili.broadcast.message.main import search_pb2 as bilibili_dot_broadcast_dot_message_dot_main_dot_search__pb2


class SearchStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CancelChatTask = channel.unary_unary(
                '/bilibili.app.search.v2.Search/CancelChatTask',
                request_serializer=bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.CancelChatTaskReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.CancelChatTaskReply.FromString,
                )
        self.GetChatResult = channel.unary_unary(
                '/bilibili.app.search.v2.Search/GetChatResult',
                request_serializer=bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.GetChatResultReq.SerializeToString,
                response_deserializer=bilibili_dot_broadcast_dot_message_dot_main_dot_search__pb2.ChatResult.FromString,
                )
        self.SearchEgg = channel.unary_unary(
                '/bilibili.app.search.v2.Search/SearchEgg',
                request_serializer=bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.SearchEggReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.SearchEggReply.FromString,
                )
        self.SubmitChatTask = channel.unary_unary(
                '/bilibili.app.search.v2.Search/SubmitChatTask',
                request_serializer=bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.SubmitChatTaskReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.SubmitChatTaskReply.FromString,
                )


class SearchServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CancelChatTask(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChatResult(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchEgg(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitChatTask(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SearchServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CancelChatTask': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelChatTask,
                    request_deserializer=bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.CancelChatTaskReq.FromString,
                    response_serializer=bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.CancelChatTaskReply.SerializeToString,
            ),
            'GetChatResult': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChatResult,
                    request_deserializer=bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.GetChatResultReq.FromString,
                    response_serializer=bilibili_dot_broadcast_dot_message_dot_main_dot_search__pb2.ChatResult.SerializeToString,
            ),
            'SearchEgg': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchEgg,
                    request_deserializer=bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.SearchEggReq.FromString,
                    response_serializer=bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.SearchEggReply.SerializeToString,
            ),
            'SubmitChatTask': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitChatTask,
                    request_deserializer=bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.SubmitChatTaskReq.FromString,
                    response_serializer=bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.SubmitChatTaskReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.search.v2.Search', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Search(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CancelChatTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.search.v2.Search/CancelChatTask',
            bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.CancelChatTaskReq.SerializeToString,
            bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.CancelChatTaskReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetChatResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.search.v2.Search/GetChatResult',
            bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.GetChatResultReq.SerializeToString,
            bilibili_dot_broadcast_dot_message_dot_main_dot_search__pb2.ChatResult.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchEgg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.search.v2.Search/SearchEgg',
            bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.SearchEggReq.SerializeToString,
            bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.SearchEggReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubmitChatTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.search.v2.Search/SubmitChatTask',
            bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.SubmitChatTaskReq.SerializeToString,
            bilibili_dot_app_dot_search_dot_v2_dot_search__pb2.SubmitChatTaskReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/relation/interfaces/api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&bilibili/relation/interfaces/api.proto\x12\x1e\x62ilibili.relation.interface.v1\"+\n\x0b\x41tSearchReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0f\n\x07keyword\x18\x02 \x01(\t\"G\n\rAtSearchReply\x12\x36\n\x05items\x18\x01 \x03(\x0b\x32\'.bilibili.relation.interface.v1.AtGroup\"h\n\x07\x41tGroup\x12\x12\n\ngroup_type\x18\x01 \x01(\x05\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x35\n\x05items\x18\x03 \x03(\x0b\x32&.bilibili.relation.interface.v1.AtItem\"]\n\x06\x41tItem\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x0c\n\x04\x66\x61ns\x18\x04 \x01(\x05\x12\x1c\n\x14official_verify_type\x18\x05 \x01(\x05\x32{\n\x11RelationInterface\x12\x66\n\x08\x41tSearch\x12+.bilibili.relation.interface.v1.AtSearchReq\x1a-.bilibili.relation.interface.v1.AtSearchReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.relation.interfaces.api_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ATSEARCHREQ']._serialized_start=74
  _globals['_ATSEARCHREQ']._serialized_end=117
  _globals['_ATSEARCHREPLY']._serialized_start=119
  _globals['_ATSEARCHREPLY']._serialized_end=190
  _globals['_ATGROUP']._serialized_start=192
  _globals['_ATGROUP']._serialized_end=296
  _globals['_ATITEM']._serialized_start=298
  _globals['_ATITEM']._serialized_end=391
  _globals['_RELATIONINTERFACE']._serialized_start=393
  _globals['_RELATIONINTERFACE']._serialized_end=516
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.polymer.contract.v1 import contract_pb2 as bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class ContractStub(object):
    """契约
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddContract = channel.unary_unary(
                '/bilibili.polymer.contract.v1.Contract/AddContract',
                request_serializer=bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.AddContractReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.AddContractV2 = channel.unary_unary(
                '/bilibili.polymer.contract.v1.Contract/AddContractV2',
                request_serializer=bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.AddContractReq.SerializeToString,
                response_deserializer=bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.AddContractReply.FromString,
                )
        self.ContractConfig = channel.unary_unary(
                '/bilibili.polymer.contract.v1.Contract/ContractConfig',
                request_serializer=bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.ContractConfigReq.SerializeToString,
                response_deserializer=bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.ContractConfigReply.FromString,
                )


class ContractServicer(object):
    """契约
    """

    def AddContract(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddContractV2(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ContractConfig(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ContractServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddContract': grpc.unary_unary_rpc_method_handler(
                    servicer.AddContract,
                    request_deserializer=bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.AddContractReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'AddContractV2': grpc.unary_unary_rpc_method_handler(
                    servicer.AddContractV2,
                    request_deserializer=bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.AddContractReq.FromString,
                    response_serializer=bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.AddContractReply.SerializeToString,
            ),
            'ContractConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.ContractConfig,
                    request_deserializer=bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.ContractConfigReq.FromString,
                    response_serializer=bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.ContractConfigReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.polymer.contract.v1.Contract', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Contract(object):
    """契约
    """

    @staticmethod
    def AddContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.polymer.contract.v1.Contract/AddContract',
            bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.AddContractReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddContractV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.polymer.contract.v1.Contract/AddContractV2',
            bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.AddContractReq.SerializeToString,
            bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.AddContractReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ContractConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.polymer.contract.v1.Contract/ContractConfig',
            bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.ContractConfigReq.SerializeToString,
            bilibili_dot_polymer_dot_contract_dot_v1_dot_contract__pb2.ContractConfigReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CheckAccountReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_NEW_FIELD_NUMBER: builtins.int
    is_new: builtins.bool
    """"""
    def __init__(
        self,
        *,
        is_new: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_new", b"is_new"]) -> None: ...

global___CheckAccountReply = CheckAccountReply

@typing_extensions.final
class CheckAccountReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    PERIODS_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""
    periods: builtins.str
    """"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        periods: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["periods", b"periods", "uid", b"uid"]) -> None: ...

global___CheckAccountReq = CheckAccountReq

@typing_extensions.final
class FavoriteTabItem(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    uri: builtins.str
    """"""
    type: builtins.str
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        uri: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type", "uri", b"uri"]) -> None: ...

global___FavoriteTabItem = FavoriteTabItem

@typing_extensions.final
class FavoriteTabReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FavoriteTabItem]:
        """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___FavoriteTabItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items"]) -> None: ...

global___FavoriteTabReply = FavoriteTabReply

@typing_extensions.final
class FavoriteTabReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___FavoriteTabReq = FavoriteTabReq
